@@ -38,9 +38,15 @@
 /** Symbol classes.  */
 typedef enum
 {
-  unknown_sym,          /**< Undefined.  */
-  token_sym,            /**< Terminal. */
-  nterm_sym             /**< Nonterminal. */
+  /** Undefined.  */
+  unknown_sym,
+  /** Declared with %type: same as Undefined, but triggered a Wyacc if
+      applied to a terminal. */
+  pct_type_sym,
+  /** Terminal. */
+  token_sym,
+  /** Nonterminal. */
+  nterm_sym
 } symbol_class;
 
 
@@ -122,7 +128,7 @@ struct sym_content
   uniqstr type_name;
 
   /** Its \c \%type's location.  */
-  location type_location;
+  location type_loc;
 
   /** Any \c \%destructor (resp. \%printer) declared specificially for this
       symbol.
@@ -134,7 +140,7 @@ struct sym_content
   code_props props[CODE_PROPS_SIZE];
 
   symbol_number number;
-  location prec_location;
+  location prec_loc;
   int prec;
   assoc assoc;
 
@@ -219,7 +225,7 @@ void symbol_precedence_set (symbol *sym, int prec, assoc a, location loc);
 /** Set the \c class associated with \c sym.
 
     Whether \c declaring means whether this class definition comes
-    from %nterm or %token.  */
+    from %nterm or %token (but not %type, prec/assoc, etc.).  */
 void symbol_class_set (symbol *sym, symbol_class class, location loc,
                        bool declaring);
 
@@ -246,7 +252,7 @@ extern symbol *accept;
 /** The user start symbol. */
 extern symbol *startsymbol;
 /** The location of the \c \%start declaration.  */
-extern location startsymbol_location;
+extern location startsymbol_loc;
 
 /** Whether a symbol declared with a type tag.  */
 extern bool tag_seen;
@@ -345,7 +351,8 @@ void semantic_type_code_props_set (semantic_type *type,
 | Symbol and semantic type tables.  |
 `----------------------------------*/
 
-/** Create the symbol and semantic type tables.  */
+/** Create the symbol and semantic type tables, and the built-in
+    symbols.  */
 void symbols_new (void);
 
 /** Free all the memory allocated for symbols and semantic types.  */
