@@ -74,6 +74,19 @@ typedef size_t uintptr_t;
 # include <xalloc.h>
 
 
+/* See https://lists.gnu.org/archive/html/bug-bison/2019-10/msg00061.html. */
+# if defined __GNUC__ && ! defined __clang__ && ! defined __ICC && __GNUC__ < 5
+#  define IGNORE_TYPE_LIMITS_BEGIN \
+     _Pragma ("GCC diagnostic push") \
+     _Pragma ("GCC diagnostic ignored \"-Wtype-limits\"")
+#  define IGNORE_TYPE_LIMITS_END \
+     _Pragma ("GCC diagnostic pop")
+# else
+#  define IGNORE_TYPE_LIMITS_BEGIN
+#  define IGNORE_TYPE_LIMITS_END
+# endif
+
+
 /*-----------------.
 | GCC extensions.  |
 `-----------------*/
@@ -249,14 +262,4 @@ typedef size_t uintptr_t;
       }                                         \
   } while (0)
 
-
-/*---------------------------------------------.
-| Debugging memory allocation (must be last).  |
-`---------------------------------------------*/
-
-# if WITH_DMALLOC
-#  define DMALLOC_FUNC_CHECK
-#  include <dmalloc.h>
-# endif /* WITH_DMALLOC */
-
 #endif  /* ! BISON_SYSTEM_H */
